pub fn group_host_assignment(
groups: &[RaftGroupId],
nodes: &[NodeId],
) -> BTreeMap<RaftGroupId, NodeId>Expand description
Full assignment of each Raft group to a host node over nodes.
pub fn group_host_assignment(
groups: &[RaftGroupId],
nodes: &[NodeId],
) -> BTreeMap<RaftGroupId, NodeId>Full assignment of each Raft group to a host node over nodes.